﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using TeamBuildScreen.Core.Models;
using Microsoft.TeamFoundation.Build.Client;

namespace TeamBuildScreen.Tfs2012.Models
{
    using Microsoft.TeamFoundation.TestManagement.Client;

    public class BuildInfo : BuildInfoBase, IBuildInfo
    {
        private IBuildDetail buildDetail;

        public BuildInfo(IBuildDetail buildDetail, string flavour, string platform, IEnumerable<ITestRun> testRuns)
        {
            this.buildDetail = buildDetail;

            if (this.buildDetail != null)
            {
                this.TestsFailed = testRuns.Select(run => run.Statistics.FailedTests).Sum();
                this.TestsPassed = testRuns.Select(run => run.Statistics.PassedTests).Sum();
                this.TestsTotal = testRuns.Select(run => run.Statistics.TotalTests).Sum();

                var configurationSummary = InformationNodeConverters.GetConfigurationSummary(buildDetail, flavour, platform);

                if (configurationSummary != null)
                {
                    this.HasWarnings = configurationSummary.TotalCompilationWarnings > 0;
                }
            }
        }

        #region IBuildInfo Members

        public bool BuildFinished
        {
            get
            {
                if (this.buildDetail != null)
                {
                    return this.buildDetail.BuildFinished;
                }
                else
                {
                    return false;
                }
            }
        }

        public DateTime FinishTime
        {
            get
            {
                if (this.buildDetail != null)
                {
                    return this.buildDetail.FinishTime;
                }
                else
                {
                    return DateTime.MinValue;
                }
            }
        }

        public TeamBuildScreen.Core.Models.BuildStatus Status
        {
            get
            {
                if (this.buildDetail != null)
                {
                    return BuildStatusConverter.Convert(this.buildDetail.Status);
                }
                else
                {
                    return TeamBuildScreen.Core.Models.BuildStatus.NotStarted;
                }
            }
        }

        public string RequestedFor
        {
            get
            {
                if (this.buildDetail != null)
                {
                    return this.buildDetail.RequestedFor;
                }
                else
                {
                    return string.Empty;
                }
            }
        }

        public DateTime StartTime
        {
            get
            {
                if (this.buildDetail != null)
                {
                    return this.buildDetail.StartTime;
                }
                else
                {
                    return DateTime.MinValue;
                }
            }
        }

        #endregion
    }
}